@@ -166,7 +166,7 @@ class AutoTraderBot():
         
         if int(self.verbosity) > 0:
                 print("AutoTraderBot assigned to analyse {}".format(instrument),
-                      "on {} timeframe using {}.".format(self.strategy_params['granularity'],
+                      "on {} timeframe using {}.\n".format(self.strategy_params['granularity'],
                                                          strategy_config['NAME']))
     
     
@@ -184,7 +184,7 @@ class AutoTraderBot():
         
         
         stream_granularity = self.base_interval
-        no_candles = self.strategy_params['period']
+        self.no_candles = self.strategy_params['period']
         
         self.AS = AutoStream(self.home_dir, 
                              self.stream_config, 
@@ -192,7 +192,7 @@ class AutoTraderBot():
                              granularity = stream_granularity,
                              record_ticks = record_ticks, 
                              record_candles = record_candles,
-                             no_candles = no_candles,
+                             no_candles = self.no_candles,
                              bot = self)
         
         stream_thread = threading.Thread(target = self.AS.start, 
@@ -238,10 +238,6 @@ class AutoTraderBot():
         Retrieves price data from AutoData.
         '''
         
-        # TODO - add time checks to download MTF data when streaming, to prevent
-        # downloading eg. 4 hour candles once every second. Instead, keep track 
-        # of time, and only download every eg. 4 hours
-        
         interval    = self.strategy_params['granularity']
         period      = self.strategy_params['period']
         price_data_path = os.path.join(self.home_dir, 'price_data')
@@ -396,7 +392,7 @@ class AutoTraderBot():
                                 # Update MTF data
                                 data = getattr(self.get_data, feed.lower())(instrument,
                                                                             granularity = granularity,
-                                                                            count=period)
+                                                                            count = period)
                             
                                 if self.check_data_alignment:
                                     data = self._verify_data_alignment(data, instrument, feed, period, 
@@ -407,6 +403,13 @@ class AutoTraderBot():
                                 
                                 # Update next time_to_download
                                 self.time_to_download[granularity] = self._next_candle_open(granularity)
+                            
+                            else:
+                                # Use previously downloaded MTF data
+                                MTF_data[granularity] = self.MTF_data[granularity]
+                        
+                        # Update self.MTF_data with latest MTF data
+                        self.MTF_data = MTF_data
                                 
                             
                 else:
@@ -431,7 +434,6 @@ class AutoTraderBot():
                                    skipinitialspace=True)
                 
                 if len(data) > 0:
-                    # TODO - use count to replace 0 above
                     data.index = pd.to_datetime(data.index, 
                                                 infer_datetime_format=True,
                                                 errors='ignore')
@@ -451,7 +453,6 @@ class AutoTraderBot():
                                                            price_data_path)
                 
                 # Fetch MTF data
-                # TODO - wrap below in conditional if len(intervals) > 1
                 MTF_data = {self.base_interval: data}
                 
                 if self.MTF_initialisation:
@@ -594,7 +595,10 @@ class AutoTraderBot():
         # First clear self.latest_orders
         self.latest_orders = []
         
-        open_positions      = self.broker.get_open_positions(self.instrument)
+        if self.scan_mode:
+            open_positions      = None
+        else:
+            open_positions      = self.broker.get_open_positions(self.instrument)
         
         # Run strategy to get signals
         signal_dict = self.strategy.generate_signal(i, open_positions)
@@ -630,7 +634,8 @@ class AutoTraderBot():
                                                                   order['order_price'])
                     print(order_string)
             else:
-                print("No signal detected.")
+                print("{}: No signal detected ({}).".format(datetime.now().strftime("%b %d %H:%M:%S"),
+                                                            self.instrument))
         
         # Check for orders placed and/or scan hits
         if int(self.notify) > 0 and self.backtest_mode is False:
@@ -666,9 +671,13 @@ class AutoTraderBot():
             if int(self.verbosity) > 0 or \
                 int(self.notify) == 0:
                 if len(self.scan_results) == 0:
-                    print("No hits detected.")
+                    print("{}: No signal detected.".format(self.instrument))
                 else:
-                    print(self.scan_results)
+                    # Scan detected hits
+                    for instrument in self.scan_results:
+                        signal = self.scan_results[instrument]['signal']
+                        signal_type = 'Long' if signal == 1 else 'Short'
+                        print(f"{instrument}: {signal_type} signal detected.")
             
             if int(self.notify) > 0:
                 # Emailing requested
@@ -677,18 +686,18 @@ class AutoTraderBot():
                     self.email_params['host_email'] is not None:
                     # There was a scanner hit and email information is provided
                     emailing.send_scan_results(self.scan_results, 
-                                                scan_details, 
-                                                self.email_params['mailing_list'],
-                                                self.email_params['host_email'])
+                                               scan_details, 
+                                               self.email_params['mailing_list'],
+                                               self.email_params['host_email'])
                 elif int(self.notify) > 1 and \
                     self.email_params['mailing_list'] is not None and \
                     self.email_params['host_email'] is not None:
                     # There was no scan hit, but notify set > 1, so send email
                     # regardless.
                     emailing.send_scan_results(self.scan_results, 
-                                                scan_details, 
-                                                self.email_params['mailing_list'],
-                                                self.email_params['host_email'])
+                                               scan_details, 
+                                               self.email_params['mailing_list'],
+                                               self.email_params['host_email'])
                     
     
     def _update_backtest(self, i):
