@@ -40,6 +40,8 @@ class Oanda():
         for a timeout error.
         '''
         
+        # TODO - improve this - currently doubles the poll rate
+        
         for atempt in range(10):
             try:
                 # Attempt basic task to check connection
@@ -605,3 +607,17 @@ class Oanda():
         
         return reduced_granularity
     
+    def get_order_book(self, instrument):
+        ''' Returns the order book of the instrument specified. '''
+        
+        response = self.api.instrument.order_book(instrument)
+        
+        return response.body['orderBook']
+        
+    def get_position_book(self, instrument):
+        ''' Returns the position book of the instrument specified. '''
+        
+        response = self.api.instrument.position_book(instrument)
+        
+        return response.body['positionBook']
+    
